==> eam-wshub-proxyclient-11.4-12-sources.jar: net/datastream/schemas/mp_fields/EMISSIONCATEGORY.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour anonymous complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}EMISSIONCATEGORYCODE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DESCRIPTION" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "emissioncategorycode",
    "description"
})
@XmlRootElement(name = "EMISSIONCATEGORY")
public class EMISSIONCATEGORY {

    @XmlElement(name = "EMISSIONCATEGORYCODE", required = true)
    protected String emissioncategorycode;
    @XmlElement(name = "DESCRIPTION")
    protected String description;

    /**
     * Obtient la valeur de la propriété emissioncategorycode.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getEMISSIONCATEGORYCODE() {
        return emissioncategorycode;
    }

    /**
     * Définit la valeur de la propriété emissioncategorycode.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setEMISSIONCATEGORYCODE(String value) {
        this.emissioncategorycode = value;
    }

    /**
     * Obtient la valeur de la propriété description.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getDESCRIPTION() {
        return description;
    }

    /**
     * Définit la valeur de la propriété description.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setDESCRIPTION(String value) {
        this.description = value;
    }

}

==> eam-wshub-proxyclient-11.7-3-sources.jar: net/datastream/schemas/mp_fields/EMISSIONCATEGORY.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}EMISSIONCATEGORYCODE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DESCRIPTION" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "emissioncategorycode",
    "description"
})
@XmlRootElement(name = "EMISSIONCATEGORY")
public class EMISSIONCATEGORY {

    @XmlElement(name = "EMISSIONCATEGORYCODE", required = true)
    protected String emissioncategorycode;
    @XmlElement(name = "DESCRIPTION")
    protected String description;

    /**
     * Gets the value of the emissioncategorycode property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getEMISSIONCATEGORYCODE() {
        return emissioncategorycode;
    }

    /**
     * Sets the value of the emissioncategorycode property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setEMISSIONCATEGORYCODE(String value) {
        this.emissioncategorycode = value;
    }

    /**
     * Gets the value of the description property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getDESCRIPTION() {
        return description;
    }

    /**
     * Sets the value of the description property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setDESCRIPTION(String value) {
        this.description = value;
    }

}
